%define title     Openbox

%define rendermajor 32
%define libobrender %mklibname obrender %rendermajor
%define obtmajor    2
%define libobt      %mklibname obt %obtmajor
%define develname   %mklibname %name -d

Summary:          Windowmanager based on the original blackbox-code
Name:             openbox
Version:          3.6.1
Release:          %mkrel 18
Group:            Graphical desktop/Other
License:          BSD
URL:              https://openbox.org/
Source0:          https://openbox.org/dist/openbox/%name-%version.tar.gz
# oxygen-theme here:
# https://box-look.org/content/show.php?content=145240
Source1:          https://box-look.org/CONTENT/content-files/145240-Oxynew.obt
# generate xdg menus
Source2:          xdg-menu-openbox
# mga default menu
Source3:          menu.xml
# run gnome-screenshot when hitting printscreen
Patch0:           01_rc.xml.dpatch
Patch1:           openbox-3.5.2-unused-libs.patch
Patch2:           openbox-default-theme.patch
Patch3:           openbox-3.6.1-upstream-patches.patch
Patch4:           openbox-3.6.1-xscreensaver-kbdbinding.patch
Patch5:           openbox-python3.patch
# The patch is proposed on https://bugzilla.icculus.org/show_bug.cgi?id=6669
# and commited to a work branch in the upstream repo
Patch6:           openbox-3.6.1-glib-2.76.patch

BuildRequires:  pkgconfig(glib-2.0) >= 2.14.0
BuildRequires:  pkgconfig(imlib2)
BuildRequires:  pkgconfig(librsvg-2.0)
BuildRequires:  pkgconfig(libstartup-notification-1.0) >= 0.8
BuildRequires:  pkgconfig(libxml-2.0) >= 2.6.0
BuildRequires:  pkgconfig(pango) >= 1.8.0
BuildRequires:  pkgconfig(pangoxft) >= 1.8.0
BuildRequires:  pkgconfig(xcursor)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xrandr)
BuildRequires:  pkgconfig(xinerama)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(sm)
BuildRequires:  pkgconfig(ice)
BuildRequires:  pkgconfig(xau)
BuildRequires:  pkgconfig(xft)
BuildRequires:  gettext-devel
Requires:       xsetroot
Requires:       python3-pyxdg
Recommends:     xscreensaver
Recommends:     xrandr
# use a virtual require to allow choose between obconf and obconf-qt (see mga#32460)
Recommends:     obox-conf
Recommends:     picom
Recommends:     picom-conf
# for PrintScreen
Recommends:     screengrab
Conflicts:      desktop-common-data < 1:3.10-2

%description
Openbox is a window manager for the X11 windowing system.
It currently runs on a large list of platforms. It was originally
based on blackbox and currently remains very similar, even using
blackbox styles (with available extensions) for its themeing.

%package -n %libobt
Summary: Libraries from openbox
Group: System/Libraries

%description -n %libobt
Openbox is a window manager for the X11 windowing system.
It currently runs on a large list of platforms. It was originally
based on blackbox and currently remains very similar, even using
blackbox styles (with available extensions) for its themeing.

%package -n %libobrender
Summary: Libraries from openbox
Group: System/Libraries

%description -n %libobrender
Openbox is a window manager for the X11 windowing system.
It currently runs on a large list of platforms. It was originally
based on blackbox and currently remains very similar, even using
blackbox styles (with available extensions) for its themeing.

%package -n %develname
Summary: Development files from openbox
Group: Development/Other
Requires: %libobt = %version-%release
Requires: %libobrender = %version-%release
Provides: %name-devel = %version-%release

%description -n %develname
Openbox is a window manager for the X11 windowing system.
It currently runs on a large list of platforms. It was originally
based on blackbox and currently remains very similar, even using
blackbox styles (with available extensions) for its themeing.

%prep
%setup -q -a1
%patch -P 0 -p0
%patch -P 1 -p1
%patch -P 2 -p0
%patch -P 3 -p1
%patch -P 4 -p1
%patch -P 5 -p1
%patch -P 6 -p1
sed -i "s|tless -->|tless -->\n<!-- Insert dynamic xdg menu -->\n<file>xdg-menu.xml</file>|g" data/rc.xml 

%build
autoreconf -fi
%configure --disable-static
%make_build DEFAULT_MENU=%{_sysconfdir}/xdg/openbox/menu.xml

%install
%make_install

mkdir -p %{buildroot}%{_datadir}/themes/oxygen/openbox-3/
install -m 0644 Oxynew/openbox-3/*.xbm Oxynew/openbox-3/themerc  %{buildroot}%{_datadir}/themes/oxygen/openbox-3/
install -Dpm 0755 %{SOURCE2} %{buildroot}%{_sysconfdir}/menu.d/openbox
install -Dpm 0644 %{SOURCE3} %{buildroot}%{_sysconfdir}/xdg/openbox/menu.xml

mkdir -p %{buildroot}%{_bindir}
cat > %{buildroot}%{_bindir}/start%{name} <<EOF
#!/bin/sh
%{_bindir}/xsetroot -solid Black
exec %{_bindir}/openbox-session
EOF
chmod 0755 %{buildroot}%{_bindir}/start%{name}

%find_lang %name

find %{buildroot} -name *.la -delete
# drop xsession files per bug#3653
rm -fr %{buildroot}%{_datadir}/xsessions

# session file
mkdir -p %{buildroot}%{_datadir}/xsessions
cat > %{buildroot}%{_datadir}/xsessions/%{name}.desktop << EOF
[Desktop Entry]
Encoding=UTF-8
Name=Openbox
Comment=Openbox
Exec=%{_bindir}/startopenbox
Icon=openbox
Type=Application
EOF

%posttrans
# (ovitters) In posttrans, $1 is always equal to 1, even in the upgrade case.
# So just run this always:
if [ -e %{_datadir}/xsessions/26Openbox.desktop ]; then
  rm -rf %{_datadir}/xsessions/26Openbox.desktop
fi
if [ -e %{_sysconfdir}/X11/dm/Sessions/26Openbox.desktop ]; then
  rm -rf %{_sysconfdir}/X11/dm/Sessions/26Openbox.desktop
fi

%files -f %name.lang
%doc AUTHORS CHANGELOG COMPLIANCE COPYING README
%doc data/*.xsd doc/*.xml
%{_docdir}/%{name}/xbm/
%{_bindir}/*
%dir %{_sysconfdir}/xdg/%{name}
%{_sysconfdir}/menu.d/%{name}
%config(noreplace) %{_sysconfdir}/xdg/%{name}/*
%ghost %config(noreplace) %{_sysconfdir}/xdg/%{name}/xdg-menu.xml
%{_libexecdir}/openbox-autostart
%{_libexecdir}/openbox-xdg-autostart
%{_datadir}/man/man1/*
%{_datadir}/gnome-session/sessions/openbox-*.session
%{_datadir}/gnome/wm-properties/openbox.desktop
%{_datadir}/applications/*.desktop
%{_datadir}/pixmaps/*
%{_datadir}/themes/*
%{_datadir}/xsessions/%{name}.desktop

%files -n %libobt
%{_libdir}/libobt.so.%{obtmajor}{,.*}

%files -n %libobrender
%{_libdir}/libobrender.so.%{rendermajor}{,.*}

%files -n %develname
%{_libdir}/pkgconfig/*.pc
%{_libdir}/*.so
%{_includedir}/%{name}/


%changelog
* Mon Jul 07 2025 umeabot <umeabot> 3.6.1-18.mga10
+ Revision: 2248479
- Mageia 10 Mass Rebuild

* Sun Mar 16 2025 wally <wally> 3.6.1-17.mga10
+ Revision: 2164972
- rebuild for libxml2 2.13.6

* Sun Dec 22 2024 pterjan <pterjan> 3.6.1-16.mga10
+ Revision: 2127999
- Rebuild for patchN deprecation
+ danf <danf>
- Update links to https:

* Tue Dec 19 2023 papoteur <papoteur> 3.6.1-15.mga10
+ Revision: 2019330
- Mass Rebuild - Python 3.12

* Sat Oct 28 2023 daviddavid <daviddavid> 3.6.1-14.mga10
+ Revision: 2002373
- recommend new virtual dependency on 'obox-conf' to allow choose between
  obconf and obconf-qt (mga#32460)

* Thu Apr 27 2023 daviddavid <daviddavid> 3.6.1-13.mga9
+ Revision: 1955192
- fix crash with new glib 2.76
  The patch is proposed on https://bugzilla.icculus.org/show_bug.cgi?id=6669

* Thu Nov 10 2022 papoteur <papoteur> 3.6.1-12.mga9
+ Revision: 1905138
- change default screenshoter to screengrab
  this avoid to Recommends GTK application with Qt (picom-conf)
  remove unuseful description

* Wed Mar 30 2022 umeabot <umeabot> 3.6.1-11.mga9
+ Revision: 1834010
- Mageia 9 Mass Rebuild
+ ovitters <ovitters>
- fix usage of  in posttrans

* Tue Feb 25 2020 daviddavid <daviddavid> 3.6.1-10.mga8
+ Revision: 1550318
- port to python3
+ umeabot <umeabot>
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Sun Sep 23 2018 umeabot <umeabot> 3.6.1-9.mga7
+ Revision: 1299979
- Mageia 7 Mass Rebuild

* Mon Feb 26 2018 kekepower <kekepower> 3.6.1-8.mga7
+ Revision: 1205257
- Add patch to enable Ctrl-Atl-l to launch xscreensaver in locked mode

* Wed Feb 14 2018 kekepower <kekepower> 3.6.1-7.mga7
+ Revision: 1200942
- Added 2 more upstream patches

* Tue Feb 13 2018 kekepower <kekepower> 3.6.1-6.mga7
+ Revision: 1200893
- Added two upstream patches
- Switched tabs for spaces in spec file
- Use make_build instead of make

* Mon Mar 06 2017 wally <wally> 3.6.1-5.mga6
+ Revision: 1089096
- create config dir under $HOME if it doesn't exist when updating menus
- use C locale when updating menus or menus won't work
- own generated menu file

* Fri Feb 24 2017 wally <wally> 3.6.1-4.mga6
+ Revision: 1087722
- remove generated xsessions .desktop file leftovers also from /etc/X11/dm/Sessions

* Fri Feb 12 2016 umeabot <umeabot> 3.6.1-3.mga6
+ Revision: 956513
- Mageia 6 Mass Rebuild

* Wed Feb 03 2016 ns80 <ns80> 3.6.1-2.mga6
+ Revision: 933562
- directly create our own xsession .desktop file
- conflict with old desktop-common-data with fndSession

* Thu Jan 28 2016 fwang <fwang> 3.6.1-1.mga6
+ Revision: 928350
- bump so version
- 3.6.1

* Wed Oct 21 2015 daviddavid <daviddavid> 3.6-2.mga6
+ Revision: 893676
- add more docs to fix build with latest rpm

* Mon Jun 22 2015 fwang <fwang> 3.6-1.mga6
+ Revision: 839121
- 3.6

* Thu Nov 06 2014 alexl <alexl> 3.5.2-8.mga5
+ Revision: 795959
- add recommends gnome-screenshot for PrintScreen

* Wed Oct 15 2014 umeabot <umeabot> 3.5.2-7.mga5
+ Revision: 739095
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 3.5.2-6.mga5
+ Revision: 683188
- Mageia 5 Mass Rebuild
+ tv <tv>
- s/uggests:/Recommends:/

* Tue Jan 07 2014 tarakbumba <tarakbumba> 3.5.2-5.mga4
+ Revision: 565485
- Add python-pyxdg requires as mentioned in openbox-xdg-autostart

* Sat Oct 19 2013 umeabot <umeabot> 3.5.2-4.mga4
+ Revision: 531963
- Mageia 4 Mass Rebuild

* Wed Aug 14 2013 fwang <fwang> 3.5.2-3.mga4
+ Revision: 466335
- drop unused libs from pkgconfig files

* Wed Aug 14 2013 fwang <fwang> 3.5.2-2.mga4
+ Revision: 466291
- update file list
- update rendermajor
- update obt major
- new version 3.5.2

* Sun Jun 23 2013 djennings <djennings> 3.5.0-10.mga4
+ Revision: 446062
- Cleaned spec file
- Added dynamic xdg menu
- cleanup BuildRequires

* Sat Feb 16 2013 fwang <fwang> 3.5.0-9.mga3
+ Revision: 398759
- update dir
- fix dir
- upload new theme
- swtich to more modern oxygen theme

* Sun Jan 13 2013 umeabot <umeabot> 3.5.0-8.mga3
+ Revision: 361910
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Apr 25 2012 obgr_seneca <obgr_seneca> 3.5.0-7.mga2
+ Revision: 233281
- fixed permissions of startopenbox script
- fixing bug #5515

* Mon Mar 05 2012 obgr_seneca <obgr_seneca> 3.5.0-6.mga2
+ Revision: 219092
- fixed file permissions on openbox oxygen theme

* Thu Dec 08 2011 fwang <fwang> 3.5.0-5.mga2
+ Revision: 178796
- drop xsessions files from package (bug#3653)
- suggests obconf now :)
- revert previous patch overwritten
- remove xlibs from pkgconfig files
- disable obconf suggests as it does not like openbox 3.5
- new version 3.5.0
- default to oxygen theme

* Tue May 03 2011 pterjan <pterjan> 3.4.11.2-5.mga1
+ Revision: 94423
- Add upstream 24 bit support (#946)

* Wed Jan 26 2011 ahmad <ahmad> 3.4.11.2-4.mga1
+ Revision: 41416
- drop old/unneeded scriptles
- imported package openbox


* Wed Dec 01 2010 Paulo Ricardo Zanoni <pzanoni@mandriva.com> 3.4.11.2-3mdv2011.0
+ Revision: 604522
- Replace X11-devel BR with only the needed libraries
  This saves around 60 package dependencies

* Sun Jul 25 2010 Ahmad Samir <ahmadsamir@mandriva.org> 3.4.11.2-2mdv2011.0
+ Revision: 559465
- suggest obconf (mdv#59732)

* Sun Jul 11 2010 Funda Wang <fwang@mandriva.org> 3.4.11.2-1mdv2011.0
+ Revision: 550586
- update to new version 3.4.11.2

* Fri Mar 26 2010 Funda Wang <fwang@mandriva.org> 3.4.11.1-1mdv2010.1
+ Revision: 527730
- New version 3.4.11
- 3 patches merged

* Wed Feb 24 2010 Michael Scherer <misc@mandriva.org> 3.4.11-2mdv2010.1
+ Revision: 510728
- fix rpmlint warning about shebang
- fix rpmlint warning about %%post
- do not disable format string gcc check, and use patch from upstream
- add comments about patchs sent to openbox developers
- fix the openbox starting script, fix #57749 thanks to dadada

  + Funda Wang <fwang@mandriva.org>
    - update source url
    - update URL

* Tue Feb 09 2010 Funda Wang <fwang@mandriva.org> 3.4.11-1mdv2010.1
+ Revision: 502586
- New version 3.4.11

* Fri Jan 08 2010 Frederik Himpe <fhimpe@mandriva.org> 3.4.10-1mdv2010.1
+ Revision: 487718
- update to new version 3.4.10

* Sun Dec 20 2009 Funda Wang <fwang@mandriva.org> 3.4.9-1mdv2010.1
+ Revision: 480317
- fix file list
- new version 3.4.9

* Thu Dec 10 2009 Funda Wang <fwang@mandriva.org> 3.4.8-1mdv2010.1
+ Revision: 476107
- new version 3.4.8

* Sun Aug 16 2009 Jani Välimaa <wally@mandriva.org> 3.4.7.2-5mdv2010.0
+ Revision: 416944
- fix gnome-settings-daemon path in one script (#49240)
- fix build

* Tue Jan 20 2009 Jérôme Soyer <saispo@mandriva.org> 3.4.7.2-4mdv2009.1
+ Revision: 331937
- Fix desktop file
- Rediff patch0

  + Anne Nicolas <ennael@mandriva.org>
    - increase order to avoid openbox being launched instead of LXDE by default

* Wed Sep 03 2008 Frederic Crozat <fcrozat@mandriva.com> 3.4.7.2-3mdv2009.0
+ Revision: 279722
- Update patch1 to work with latest gnome-session

* Fri Aug 08 2008 Thierry Vignaud <tv@mandriva.org> 3.4.7.2-2mdv2009.0
+ Revision: 268350
- rebuild early 2009.0 package (before pixel changes)

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

* Sat May 03 2008 Funda Wang <fwang@mandriva.org> 3.4.7.2-1mdv2009.0
+ Revision: 200690
- New version 3.4.7.2

* Thu Feb 07 2008 Funda Wang <fwang@mandriva.org> 3.4.6.1-1mdv2008.1
+ Revision: 163360
- New version 3.4.6.1

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request
    - buildrequires X11-devel instead of XFree86-devel

* Mon Oct 22 2007 Jérôme Soyer <saispo@mandriva.org> 3.4.4-1mdv2008.1
+ Revision: 101163
- Add BR
- New release 3.4.4
- temp
- temp

* Mon Aug 06 2007 Frederic Crozat <fcrozat@mandriva.com> 3.3.1-2mdv2008.0
+ Revision: 59352
- Fix incorrect path for wmsession file


* Sat Dec 30 2006 Olivier Thauvin <nanardon@mandriva.org> 3.3.1-1mdv2007.0
+ Revision: 102819
- 3.3.1

* Sun Jul 16 2006 Olivier Thauvin <nanardon@mandriva.org> 3.2-2mdv2007.0
+ Revision: 41300
- fix path in script
- build the from the spec
- adjust requirement
- do no longer use X11R6 dir
- rebuild
- spec cleanup
- Import openbox

* Thu Apr 22 2004 Olivier Thauvin <thauvin@aerov.jussieu.fr> 3.2-1mdk
- 3.2

* Mon Jan 05 2004 Götz Waschk <waschk@linux-mandrake.com> 3.1-2mdk
- fix buildrequires
- remove broken menu script
- fix description
- fix startopenbox script
- move files around

